@@ -369,10 +369,12 @@ class Badminton():
             self.pay()
             sys.exit()
 
-
-if __name__ == '__main__':
+def main():
     parser = argparse.ArgumentParser(description='预定中山大学珠海校区羽毛球场地')
     parser.add_argument('-c', '--config', type=str, help='配置文件路径', required=True)
     par = parser.parse_args()
     badminton = Badminton(par.config)
     badminton.run()
+
+if __name__ == '__main__':
+    main()
